@@ -1,58 +1,59 @@
 //
-// File AssociationGraphImplObserver.h
-// Created by: Thomas Bigot
-// Last modification : vendredi 4 novembre 2016, à 10h 21
+// File: AssociationGraphImplObserver.h
+// Authors:
+//   Thomas Bigot
+// Last modified: 2017-06-27
 //
 
 /*
-   Copyright or © or Copr. Bio++ Development Team, (November 17, 2004)
+  Copyright or © or Copr. Bio++ Development Team, (November 17, 2004)
+  
+  This software is a computer program whose purpose is to provide utilitary
+  classes. This file belongs to the Bio++ Project.
+  
+  This software is governed by the CeCILL license under French law and
+  abiding by the rules of distribution of free software. You can use,
+  modify and/ or redistribute the software under the terms of the CeCILL
+  license as circulated by CEA, CNRS and INRIA at the following URL
+  "http://www.cecill.info".
+  
+  As a counterpart to the access to the source code and rights to copy,
+  modify and redistribute granted by the license, users are provided only
+  with a limited warranty and the software's author, the holder of the
+  economic rights, and the successive licensors have only limited
+  liability.
+  
+  In this respect, the user's attention is drawn to the risks associated
+  with loading, using, modifying and/or developing or reproducing the
+  software by the user in light of its specific status of free software,
+  that may mean that it is complicated to manipulate, and that also
+  therefore means that it is reserved for developers and experienced
+  professionals having in-depth computer knowledge. Users are therefore
+  encouraged to load and test the software's suitability as regards their
+  requirements in conditions enabling the security of their systems and/or
+  data to be ensured and, more generally, to use and operate it in the
+  same conditions as regards security.
+  
+  The fact that you are presently reading this means that you have had
+  knowledge of the CeCILL license and that you accept its terms.
+*/
 
-   This software is a computer program whose purpose is to provide utilitary
-   classes. This file belongs to the Bio++ Project.
+#ifndef BPP_GRAPH_ASSOCIATIONGRAPHIMPLOBSERVER_H
+#define BPP_GRAPH_ASSOCIATIONGRAPHIMPLOBSERVER_H
 
-   This software is governed by the CeCILL  license under French law and
-   abiding by the rules of distribution of free software.  You can  use,
-   modify and/ or redistribute the software under the terms of the CeCILL
-   license as circulated by CEA, CNRS and INRIA at the following URL
-   "http://www.cecill.info".
-
-   As a counterpart to the access to the source code and  rights to copy,
-   modify and redistribute granted by the license, users are provided only
-   with a limited warranty  and the software's author,  the holder of the
-   economic rights,  and the successive licensors  have only  limited
-   liability.
-
-   In this respect, the user's attention is drawn to the risks associated
-   with loading,  using,  modifying and/or developing or reproducing the
-   software by the user in light of its specific status of free software,
-   that may mean  that it is complicated to manipulate,  and  that  also
-   therefore means  that it is reserved for developers  and  experienced
-   professionals having in-depth computer knowledge. Users are therefore
-   encouraged to load and test the software's suitability as regards their
-   requirements in conditions enabling the security of their systems and/or
-   data to be ensured and,  more generally, to use and operate it in the
-   same conditions as regards security.
-
-   The fact that you are presently reading this means that you have had
-   knowledge of the CeCILL license and that you accept its terms.
- */
-
-#ifndef _ASSOCIATION_GRAPH_IMPL_OBSERVER_HPP_
-#define _ASSOCIATION_GRAPH_IMPL_OBSERVER_HPP_
+#include <iostream>
+#include <map>
+#include <memory>
+#include <ostream>
+#include <type_traits>
+#include <vector>
 
+#include "../Clonable.h"
+#include "../Exceptions.h"
+#include "../Text/TextTools.h"
 #include "AssociationGraphObserver.h"
 #include "GlobalGraph.h"
 
-#include "../Exceptions.h"
-#include "../Clonable.h"
-
-#include <vector>
-#include <map>
-#include <iostream>
-#include <ostream>
-#include <memory>
-#include <type_traits>
-
 namespace bpp
 {
 template<class N, class E, class GraphImpl>
@@ -196,7 +197,7 @@ public:
    */
 
   AssociationGraphImplObserver(bool directed = false) :
-    subjectGraph_(new GraphImpl(directed)),
+    subjectGraph_(std::shared_ptr<GraphImpl>(new GraphImpl(directed))),
     graphidToN_(),
     graphidToE_(),
     NToGraphid_(),
@@ -215,7 +216,7 @@ public:
    */
 
   AssociationGraphImplObserver(std::shared_ptr<GraphImpl> subjectGraph = 00) :
-    subjectGraph_(subjectGraph ? subjectGraph : new GraphImpl()),
+    subjectGraph_(subjectGraph ? subjectGraph : std::shared_ptr<GraphImpl>(new GraphImpl(true))),
     graphidToN_(),
     graphidToE_(),
     NToGraphid_(),
@@ -525,6 +526,9 @@ public:
    */
   void associateNode(std::shared_ptr<N>  nodeObject, NodeGraphid graphNode)
   {
+    if (NToGraphid_.find(nodeObject) != NToGraphid_.end())
+      throw Exception("AssociationGraphImplObserver::associateNode : node already exists");
+
     // nodes vector must be the right size. Eg: to store a node with
     // the ID 3, the vector must be of size 4: {0,1,2,3} (size = 4)
     if (graphidToN_.size() < graphNode + 1)
@@ -542,7 +546,10 @@ public:
    */
   void associateEdge(std::shared_ptr<E>  edgeObject, EdgeGraphid graphEdge)
   {
-    // nodes vector must be the right size. Eg: to store an edge with
+    if (EToGraphid_.find(edgeObject) != EToGraphid_.end())
+      throw Exception("AssociationGraphImplObserver::associateEdge : edge already exists");
+    
+    // edges vector must be the right size. Eg: to store an edge with
     // the ID 3, the vector must be of size 4: {0,1,2,3} (size = 4)
     if (graphidToE_.size() < graphEdge + 1)
       graphidToE_.resize(graphEdge + 1);
@@ -1032,6 +1039,22 @@ public:
     return leavesToReturn;
   }
 
+  std::vector<typename AssociationGraphObserver<N, E>::NodeIndex > getAllLeavesIndexes() const
+  {
+    std::vector<typename AssociationGraphObserver<N, E>::NodeIndex > leavesToReturn;
+
+    // fetching all the graph Leaves
+    std::vector<NodeGraphid> graphLeaves = getGraph()->getAllLeaves();
+    // testing if they are defined in this observer
+    for (typename std::vector<NodeGraphid>::iterator currGraphLeave = graphLeaves.begin(); currGraphLeave != graphLeaves.end(); currGraphLeave++)
+    {
+      std::shared_ptr<N>  foundLeafObject = graphidToN_.at(*currGraphLeave);
+      if (foundLeafObject != 00)
+        leavesToReturn.push_back(getNodeIndex(foundLeafObject));
+    }
+    return leavesToReturn;
+  }
+
   /**
    * Get all the inner nodes of a graph, ie, nodes with degree >= 2.
    * @return a vector containing the inner nodes.
@@ -1083,16 +1106,29 @@ public:
     return indexesToReturn;
   }
 
+  std::vector<EdgeIndex> getAllEdgesIndexes() const
+  {
+    std::vector<typename AssociationGraphObserver<N, E>::EdgeIndex > indexesToReturn;
+    for (typename std::vector<std::shared_ptr<E> >::const_iterator currEdgeObject = graphidToE_.begin(); currEdgeObject != graphidToE_.end(); currEdgeObject++)
+    {
+      if (*currEdgeObject != 00)
+      {
+        indexesToReturn.push_back(getEdgeIndex(*currEdgeObject));
+      }
+    }
+    return indexesToReturn;
+  }
+
 
   template<class GraphIterator, bool is_const>
   class EdgeIteratorClass :
     public AssociationGraphObserver<N, E>::EdgeIterator
   {
-private:
+  private:
     EdgesIteratorClass<GraphIterator, is_const> it_;
     const AssociationGraphImplObserver<N, E, GraphImpl>& agio_;
-
-public:
+    
+  public:
     EdgeIteratorClass<GraphIterator, is_const>(AssociationGraphImplObserver<N, E, GraphImpl> &agio) : it_(*agio.getGraph()),
       agio_(agio) { start(); };
 
@@ -1183,6 +1219,11 @@ public:
     return getGraph()->isLeaf(this->getNodeGraphid(node));
   }
 
+  bool isLeaf(const NodeIndex nodeid) const
+  {
+    return getGraph()->isLeaf(this->getNodeGraphid(getNode(nodeid)));
+  }
+
   /**
    * Get nodes located at the extremities of an edge
    * @param edge an edge
@@ -1328,5 +1369,4 @@ public:
 template<class N, class E>
 using AssociationGlobalGraphObserver = AssociationGraphImplObserver<N, E, GlobalGraph>;
 }
-
-#endif
+#endif // BPP_GRAPH_ASSOCIATIONGRAPHIMPLOBSERVER_H
