@@ -111,7 +111,6 @@ AbstractParameterAliasable::~AbstractParameterAliasable()
 }
 
 void AbstractParameterAliasable::aliasParameters(const std::string& p1, const std::string& p2)
-throw (ParameterNotFoundException, Exception)
 {
   // In case this is the first time we call this method:
   if (getNumberOfParameters() > 0 && independentParameters_.size() == 0)
@@ -173,7 +172,7 @@ void AbstractParameterAliasable::aliasParameters(map<string, string>& unparsedPa
   for (size_t i = 0; i < pl.size(); i++)
   {
     if (unparsedParams.find(pl[i].getName()) == unparsedParams.end())
-      plpars.addParameter(*pl[i].clone());
+      plpars.addParameter(pl[i].clone());
   }
 
   size_t unp_s = unparsedParams.size();
@@ -214,7 +213,6 @@ void AbstractParameterAliasable::aliasParameters(map<string, string>& unparsedPa
 
 
 void AbstractParameterAliasable::unaliasParameters(const std::string& p1, const std::string& p2)
-throw (ParameterNotFoundException, Exception)
 {
   if (!hasParameter(p1))
     throw ParameterNotFoundException("AbstractParameterAliasable::unaliasParameters", p1);
