@@ -89,7 +89,7 @@ public:
    * @throw UnvalidStateAlphabetException if the new alphabet is uncorrect (for instance is NULL pointer).
    */
   
-  void setHmmStateAlphabet(const HmmStateAlphabet* stateAlphabet) throw (HmmUnvalidAlphabetException);
+  void setHmmStateAlphabet(const HmmStateAlphabet* stateAlphabet);
    
   /**
    * @return The number of states in the model.
