@@ -132,7 +132,7 @@ namespace bpp {
                           HmmStateAlphabet* hiddenAlphabet,
                           HmmTransitionMatrix* transitionMatrix,
                           HmmEmissionProbabilities* emissionProbabilities,
-                          const std::string& prefix) throw (Exception);
+                          const std::string& prefix);
     
     RescaledHmmLikelihood(const RescaledHmmLikelihood& lik):
     AbstractHmmLikelihood(lik),
@@ -206,12 +206,12 @@ namespace bpp {
 
     const std::vector<size_t>& getBreakPoints() const { return breakPoints_; }
 
-    void setParameters(const ParameterList& pl) throw (Exception)
+    void setParameters(const ParameterList& pl)
     {
       setParametersValues(pl);
     }
 
-    double getValue() const throw (Exception) { return -logLik_; }
+    double getValue() const { return -logLik_; }
 
     double getLogLikelihood() const { return logLik_; }
 
@@ -229,7 +229,7 @@ namespace bpp {
 
     Vdouble getHiddenStatesPosteriorProbabilitiesForASite(size_t site) const;
 
-    void getHiddenStatesPosteriorProbabilities(std::vector< std::vector<double> >& probs, bool append = false) const throw (Exception);
+    void getHiddenStatesPosteriorProbabilities(std::vector< std::vector<double> >& probs, bool append = false) const;
 
     
   protected:
